==> apigatewaydynamodb-1.81.0-sources.jar: software/amazon/awsconstructs/services/apigatewaydynamodb/ApiGatewayToDynamoDB.java <==
package software.amazon.awsconstructs.services.apigatewaydynamodb;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.17.1 (build 2bac5fd)", date = "2021-01-14T19:02:33.304Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.apigatewaydynamodb.$Module.class, fqn = "@aws-solutions-constructs/aws-apigateway-dynamodb.ApiGatewayToDynamoDB")
public class ApiGatewayToDynamoDB extends software.amazon.awscdk.core.Construct {

    protected ApiGatewayToDynamoDB(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApiGatewayToDynamoDB(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public ApiGatewayToDynamoDB(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDBProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.RestApi getApiGateway() {
        return software.amazon.jsii.Kernel.get(this, "apiGateway", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.RestApi.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Role getApiGatewayCloudWatchRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayCloudWatchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.LogGroup getApiGatewayLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Role getApiGatewayRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.Table getDynamoTable() {
        return software.amazon.jsii.Kernel.get(this, "dynamoTable", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.dynamodb.Table.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDBProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDBProps.Builder();
        }

        /**
         * Whether to deploy API Gateway Method for Create operation on DynamoDB table.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param allowCreateOperation Whether to deploy API Gateway Method for Create operation on DynamoDB table. This parameter is required.
         */
        public Builder allowCreateOperation(final java.lang.Boolean allowCreateOperation) {
            this.props.allowCreateOperation(allowCreateOperation);
            return this;
        }

        /**
         * Whether to deploy API Gateway Method for Delete operation on DynamoDB table.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param allowDeleteOperation Whether to deploy API Gateway Method for Delete operation on DynamoDB table. This parameter is required.
         */
        public Builder allowDeleteOperation(final java.lang.Boolean allowDeleteOperation) {
            this.props.allowDeleteOperation(allowDeleteOperation);
            return this;
        }

        /**
         * Whether to deploy API Gateway Method for Read operation on DynamoDB table.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param allowReadOperation Whether to deploy API Gateway Method for Read operation on DynamoDB table. This parameter is required.
         */
        public Builder allowReadOperation(final java.lang.Boolean allowReadOperation) {
            this.props.allowReadOperation(allowReadOperation);
            return this;
        }

        /**
         * Whether to deploy API Gateway Method for Update operation on DynamoDB table.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param allowUpdateOperation Whether to deploy API Gateway Method for Update operation on DynamoDB table. This parameter is required.
         */
        public Builder allowUpdateOperation(final java.lang.Boolean allowUpdateOperation) {
            this.props.allowUpdateOperation(allowUpdateOperation);
            return this;
        }

        /**
         * Optional user-provided props to override the default props for the API Gateway.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param apiGatewayProps Optional user-provided props to override the default props for the API Gateway. This parameter is required.
         */
        public Builder apiGatewayProps(final software.amazon.awscdk.services.apigateway.RestApiProps apiGatewayProps) {
            this.props.apiGatewayProps(apiGatewayProps);
            return this;
        }

        /**
         * API Gateway Request template for Create method, required if allowCreateOperation set to true.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param createRequestTemplate API Gateway Request template for Create method, required if allowCreateOperation set to true. This parameter is required.
         */
        public Builder createRequestTemplate(final java.lang.String createRequestTemplate) {
            this.props.createRequestTemplate(createRequestTemplate);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param dynamoTableProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder dynamoTableProps(final software.amazon.awscdk.services.dynamodb.TableProps dynamoTableProps) {
            this.props.dynamoTableProps(dynamoTableProps);
            return this;
        }

        /**
         * Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingTableObj Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. This parameter is required.
         */
        public Builder existingTableObj(final software.amazon.awscdk.services.dynamodb.Table existingTableObj) {
            this.props.existingTableObj(existingTableObj);
            return this;
        }

        /**
         * API Gateway Request template for Update method, required if allowUpdateOperation set to true.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param updateRequestTemplate API Gateway Request template for Update method, required if allowUpdateOperation set to true. This parameter is required.
         */
        public Builder updateRequestTemplate(final java.lang.String updateRequestTemplate) {
            this.props.updateRequestTemplate(updateRequestTemplate);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB}.
         */
        @Override
        public software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB build() {
            return new software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> apigatewaydynamodb-1.100.0-sources.jar: software/amazon/awsconstructs/services/apigatewaydynamodb/ApiGatewayToDynamoDB.java <==
package software.amazon.awsconstructs.services.apigatewaydynamodb;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-04-28T20:55:24.311Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.apigatewaydynamodb.$Module.class, fqn = "@aws-solutions-constructs/aws-apigateway-dynamodb.ApiGatewayToDynamoDB")
public class ApiGatewayToDynamoDB extends software.amazon.awscdk.core.Construct {

    protected ApiGatewayToDynamoDB(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ApiGatewayToDynamoDB(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public ApiGatewayToDynamoDB(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDBProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.RestApi getApiGateway() {
        return software.amazon.jsii.Kernel.get(this, "apiGateway", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.RestApi.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Role getApiGatewayCloudWatchRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayCloudWatchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.LogGroup getApiGatewayLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.Role getApiGatewayRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.Table getDynamoTable() {
        return software.amazon.jsii.Kernel.get(this, "dynamoTable", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.dynamodb.Table.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDBProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDBProps.Builder();
        }

        /**
         * Whether to deploy API Gateway Method for Create operation on DynamoDB table.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param allowCreateOperation Whether to deploy API Gateway Method for Create operation on DynamoDB table. This parameter is required.
         */
        public Builder allowCreateOperation(final java.lang.Boolean allowCreateOperation) {
            this.props.allowCreateOperation(allowCreateOperation);
            return this;
        }

        /**
         * Whether to deploy API Gateway Method for Delete operation on DynamoDB table.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param allowDeleteOperation Whether to deploy API Gateway Method for Delete operation on DynamoDB table. This parameter is required.
         */
        public Builder allowDeleteOperation(final java.lang.Boolean allowDeleteOperation) {
            this.props.allowDeleteOperation(allowDeleteOperation);
            return this;
        }

        /**
         * Whether to deploy API Gateway Method for Read operation on DynamoDB table.
         * <p>
         * Default: - true
         * <p>
         * @return {@code this}
         * @param allowReadOperation Whether to deploy API Gateway Method for Read operation on DynamoDB table. This parameter is required.
         */
        public Builder allowReadOperation(final java.lang.Boolean allowReadOperation) {
            this.props.allowReadOperation(allowReadOperation);
            return this;
        }

        /**
         * Whether to deploy API Gateway Method for Update operation on DynamoDB table.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param allowUpdateOperation Whether to deploy API Gateway Method for Update operation on DynamoDB table. This parameter is required.
         */
        public Builder allowUpdateOperation(final java.lang.Boolean allowUpdateOperation) {
            this.props.allowUpdateOperation(allowUpdateOperation);
            return this;
        }

        /**
         * Optional user-provided props to override the default props for the API Gateway.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param apiGatewayProps Optional user-provided props to override the default props for the API Gateway. This parameter is required.
         */
        public Builder apiGatewayProps(final software.amazon.awscdk.services.apigateway.RestApiProps apiGatewayProps) {
            this.props.apiGatewayProps(apiGatewayProps);
            return this;
        }

        /**
         * API Gateway Request template for Create method, required if allowCreateOperation set to true.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param createRequestTemplate API Gateway Request template for Create method, required if allowCreateOperation set to true. This parameter is required.
         */
        public Builder createRequestTemplate(final java.lang.String createRequestTemplate) {
            this.props.createRequestTemplate(createRequestTemplate);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param dynamoTableProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder dynamoTableProps(final software.amazon.awscdk.services.dynamodb.TableProps dynamoTableProps) {
            this.props.dynamoTableProps(dynamoTableProps);
            return this;
        }

        /**
         * Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingTableObj Existing instance of DynamoDB table object, If this is set then the dynamoTableProps is ignored. This parameter is required.
         */
        public Builder existingTableObj(final software.amazon.awscdk.services.dynamodb.Table existingTableObj) {
            this.props.existingTableObj(existingTableObj);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * API Gateway Request template for Update method, required if allowUpdateOperation set to true.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param updateRequestTemplate API Gateway Request template for Update method, required if allowUpdateOperation set to true. This parameter is required.
         */
        public Builder updateRequestTemplate(final java.lang.String updateRequestTemplate) {
            this.props.updateRequestTemplate(updateRequestTemplate);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB}.
         */
        @Override
        public software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB build() {
            return new software.amazon.awsconstructs.services.apigatewaydynamodb.ApiGatewayToDynamoDB(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
